import * as react from 'react';
import { InputHTMLAttributes, ReactNode, FC } from 'react';
import { IconCSS, IconProps } from '@pikas-ui/icons';
import { PikasCSS, PikasShadow, PikasRadius, PikasFontSize, PikasColor } from '@pikas-ui/styles';
import { TooltipCSS } from '@pikas-ui/tooltip';

declare const multiInputFieldType: {
    readonly color: true;
    readonly date: true;
    readonly 'datetime-local': true;
    readonly email: true;
    readonly hidden: true;
    readonly month: true;
    readonly number: true;
    readonly password: true;
    readonly search: true;
    readonly tel: true;
    readonly text: true;
    readonly time: true;
    readonly url: true;
    readonly week: true;
};
type MultiInputFieldType = keyof typeof multiInputFieldType;
declare const multiInputFieldPadding: {
    readonly xs: true;
    readonly sm: true;
    readonly md: true;
    readonly lg: true;
    readonly xl: true;
};
type MultiInputFieldPadding = keyof typeof multiInputFieldPadding;
declare const multiInputFieldGap: {
    readonly xs: true;
    readonly sm: true;
    readonly md: true;
    readonly lg: true;
    readonly xl: true;
};
type MultiInputFieldGap = keyof typeof multiInputFieldGap;
type MultiInputFieldCSS = {
    container?: PikasCSS;
    inputContainer?: PikasCSS;
    inputContent?: PikasCSS;
    input?: PikasCSS;
    left?: PikasCSS;
    right?: PikasCSS;
    leftIcon?: IconCSS;
    rightIcon?: IconCSS;
    infoTooltip?: TooltipCSS;
    infoIcon?: IconCSS;
    label?: PikasCSS;
    description?: PikasCSS;
    textError?: PikasCSS;
    required?: PikasCSS;
    badge?: PikasCSS;
};
type MultiInputFieldProps = InputHTMLAttributes<HTMLInputElement> & {
    css?: MultiInputFieldCSS;
    id?: string;
    label?: ReactNode | string;
    boxShadow?: PikasShadow | 'none';
    borderRadius?: PikasRadius;
    padding?: MultiInputFieldPadding;
    gap?: MultiInputFieldGap;
    fontSize?: PikasFontSize;
    borderColorName?: PikasColor;
    borderColorHex?: string;
    borderWidth?: number;
    colorName?: PikasColor;
    colorHex?: string;
    placeholderColorName?: PikasColor;
    placeholderColorHex?: string;
    backgroundColorName?: PikasColor;
    backgroundColorHex?: string;
    textError?: string;
    onChange?: (values: string[]) => void;
    autoComplete?: string;
    LeftIcon?: FC<IconProps>;
    RightIcon?: FC<IconProps>;
    leftIconColorName?: PikasColor;
    leftIconColorHex?: string;
    rightIconColorName?: PikasColor;
    rightIconColorHex?: string;
    leftIconSize?: number;
    rightIconSize?: number;
    leftChildren?: ReactNode;
    rightChildren?: ReactNode;
    min?: number;
    max?: number;
    outline?: boolean;
    description?: string;
    width?: number | string;
    maxWidth?: number | string;
    minWidth?: number | string;
    info?: ReactNode;
    data?: DOMStringMap;
    type?: MultiInputFieldType;
    defaultValues?: string[];
};
declare const MultiInputField: react.ForwardRefExoticComponent<InputHTMLAttributes<HTMLInputElement> & {
    css?: MultiInputFieldCSS | undefined;
    id?: string | undefined;
    label?: ReactNode | string;
    boxShadow?: "none" | "xs" | "sm" | "md" | "lg" | "xl" | "2xl" | "top-xs" | "top-sm" | "top-md" | "top-lg" | "top-xl" | "top-2xl" | "bottom-xs" | "bottom-sm" | "bottom-md" | "bottom-lg" | "bottom-xl" | "bottom-2xl" | "inner-xs" | "inner-sm" | "inner-md" | "inner-lg" | "inner-xl" | "inner-2xl" | "inner-top-xs" | "inner-top-sm" | "inner-top-md" | "inner-top-lg" | "inner-top-xl" | "inner-top-2xl" | "inner-bottom-xs" | "inner-bottom-sm" | "inner-bottom-md" | "inner-bottom-lg" | "inner-bottom-xl" | "inner-bottom-2xl" | undefined;
    borderRadius?: "none" | "xs" | "sm" | "md" | "lg" | "xl" | "2xl" | "3xl" | "full" | undefined;
    padding?: "xs" | "sm" | "md" | "lg" | "xl" | undefined;
    gap?: "xs" | "sm" | "md" | "lg" | "xl" | undefined;
    fontSize?: "em-3x-small" | "em-2x-small" | "em-x-small" | "em-small" | "em-base" | "em-large" | "em-x-large" | "em-2x-large" | "em-3x-large" | "em-4x-large" | "em-5x-large" | "em-6x-large" | "em-7x-large" | "em-8x-large" | "em-9x-large" | "rem-3x-small" | "rem-2x-small" | "rem-x-small" | "rem-small" | "rem-base" | "rem-large" | "rem-x-large" | "rem-2x-large" | "rem-3x-large" | "rem-4x-large" | "rem-5x-large" | "rem-6x-large" | "rem-7x-large" | "rem-8x-large" | "rem-9x-large" | undefined;
    borderColorName?: "background" | "transparent" | "primary-darker" | "primary-dark" | "primary" | "primary-light" | "primary-lighter" | "primary-lightest-2" | "primary-lightest-1" | "primary-fixed-darker" | "primary-fixed-dark" | "primary-fixed" | "primary-fixed-light" | "primary-fixed-lighter" | "primary-fixed-lightest-2" | "primary-fixed-lightest-1" | "secondary-darker" | "secondary-dark" | "secondary" | "secondary-light" | "secondary-lighter" | "secondary-lightest-2" | "secondary-lightest-1" | "secondary-fixed-darker" | "secondary-fixed-dark" | "secondary-fixed" | "secondary-fixed-light" | "secondary-fixed-lighter" | "secondary-fixed-lightest-2" | "secondary-fixed-lightest-1" | "tertiary-darker" | "tertiary-dark" | "tertiary" | "tertiary-light" | "tertiary-lighter" | "tertiary-lightest-2" | "tertiary-lightest-1" | "tertiary-fixed-darker" | "tertiary-fixed-dark" | "tertiary-fixed" | "tertiary-fixed-light" | "tertiary-fixed-lighter" | "tertiary-fixed-lightest-2" | "tertiary-fixed-lightest-1" | "black" | "black-2" | "black-light" | "black-lighter" | "black-lightest-2" | "black-lightest-1" | "black-fixed" | "black-fixed-light" | "black-fixed-lighter" | "black-fixed-lightest-2" | "black-fixed-lightest-1" | "white" | "white-2" | "white-light" | "white-lighter" | "white-lightest-2" | "white-lightest-1" | "white-fixed" | "white-fixed-light" | "white-fixed-lighter" | "white-fixed-lightest-2" | "white-fixed-lightest-1" | "gray-darker" | "gray-dark" | "gray" | "gray-light" | "gray-lighter" | "gray-lightest-2" | "gray-lightest-1" | "gray-fixed-darker" | "gray-fixed-dark" | "gray-fixed" | "gray-fixed-light" | "gray-fixed-lighter" | "gray-fixed-lightest-2" | "gray-fixed-lightest-1" | "success-darker" | "success-dark" | "success" | "success-light" | "success-lighter" | "success-lightest-2" | "success-lightest-1" | "success-fixed-darker" | "success-fixed-dark" | "success-fixed" | "success-fixed-light" | "success-fixed-lighter" | "success-fixed-lightest-2" | "success-fixed-lightest-1" | "warning-darker" | "warning-dark" | "warning" | "warning-light" | "warning-lighter" | "warning-lightest-2" | "warning-lightest-1" | "warning-fixed-darker" | "warning-fixed-dark" | "warning-fixed" | "warning-fixed-light" | "warning-fixed-lighter" | "warning-fixed-lightest-2" | "warning-fixed-lightest-1" | "danger-darker" | "danger-dark" | "danger" | "danger-light" | "danger-lighter" | "danger-lightest-2" | "danger-lightest-1" | "danger-fixed-darker" | "danger-fixed-dark" | "danger-fixed" | "danger-fixed-light" | "danger-fixed-lighter" | "danger-fixed-lightest-2" | "danger-fixed-lightest-1" | "info-darker" | "info-dark" | "info" | "info-light" | "info-lighter" | "info-lightest-2" | "info-lightest-1" | "info-fixed-darker" | "info-fixed-dark" | "info-fixed" | "info-fixed-light" | "info-fixed-lighter" | "info-fixed-lightest-2" | "info-fixed-lightest-1" | "background-darker" | "background-dark" | "background-light" | "background-lighter" | "background-lightest-2" | "background-lightest-1" | "background-fixed-darker" | "background-fixed-dark" | "background-fixed" | "background-fixed-light" | "background-fixed-lighter" | "background-fixed-lightest-2" | "background-fixed-lightest-1" | undefined;
    borderColorHex?: string | undefined;
    borderWidth?: number | undefined;
    colorName?: "background" | "transparent" | "primary-darker" | "primary-dark" | "primary" | "primary-light" | "primary-lighter" | "primary-lightest-2" | "primary-lightest-1" | "primary-fixed-darker" | "primary-fixed-dark" | "primary-fixed" | "primary-fixed-light" | "primary-fixed-lighter" | "primary-fixed-lightest-2" | "primary-fixed-lightest-1" | "secondary-darker" | "secondary-dark" | "secondary" | "secondary-light" | "secondary-lighter" | "secondary-lightest-2" | "secondary-lightest-1" | "secondary-fixed-darker" | "secondary-fixed-dark" | "secondary-fixed" | "secondary-fixed-light" | "secondary-fixed-lighter" | "secondary-fixed-lightest-2" | "secondary-fixed-lightest-1" | "tertiary-darker" | "tertiary-dark" | "tertiary" | "tertiary-light" | "tertiary-lighter" | "tertiary-lightest-2" | "tertiary-lightest-1" | "tertiary-fixed-darker" | "tertiary-fixed-dark" | "tertiary-fixed" | "tertiary-fixed-light" | "tertiary-fixed-lighter" | "tertiary-fixed-lightest-2" | "tertiary-fixed-lightest-1" | "black" | "black-2" | "black-light" | "black-lighter" | "black-lightest-2" | "black-lightest-1" | "black-fixed" | "black-fixed-light" | "black-fixed-lighter" | "black-fixed-lightest-2" | "black-fixed-lightest-1" | "white" | "white-2" | "white-light" | "white-lighter" | "white-lightest-2" | "white-lightest-1" | "white-fixed" | "white-fixed-light" | "white-fixed-lighter" | "white-fixed-lightest-2" | "white-fixed-lightest-1" | "gray-darker" | "gray-dark" | "gray" | "gray-light" | "gray-lighter" | "gray-lightest-2" | "gray-lightest-1" | "gray-fixed-darker" | "gray-fixed-dark" | "gray-fixed" | "gray-fixed-light" | "gray-fixed-lighter" | "gray-fixed-lightest-2" | "gray-fixed-lightest-1" | "success-darker" | "success-dark" | "success" | "success-light" | "success-lighter" | "success-lightest-2" | "success-lightest-1" | "success-fixed-darker" | "success-fixed-dark" | "success-fixed" | "success-fixed-light" | "success-fixed-lighter" | "success-fixed-lightest-2" | "success-fixed-lightest-1" | "warning-darker" | "warning-dark" | "warning" | "warning-light" | "warning-lighter" | "warning-lightest-2" | "warning-lightest-1" | "warning-fixed-darker" | "warning-fixed-dark" | "warning-fixed" | "warning-fixed-light" | "warning-fixed-lighter" | "warning-fixed-lightest-2" | "warning-fixed-lightest-1" | "danger-darker" | "danger-dark" | "danger" | "danger-light" | "danger-lighter" | "danger-lightest-2" | "danger-lightest-1" | "danger-fixed-darker" | "danger-fixed-dark" | "danger-fixed" | "danger-fixed-light" | "danger-fixed-lighter" | "danger-fixed-lightest-2" | "danger-fixed-lightest-1" | "info-darker" | "info-dark" | "info" | "info-light" | "info-lighter" | "info-lightest-2" | "info-lightest-1" | "info-fixed-darker" | "info-fixed-dark" | "info-fixed" | "info-fixed-light" | "info-fixed-lighter" | "info-fixed-lightest-2" | "info-fixed-lightest-1" | "background-darker" | "background-dark" | "background-light" | "background-lighter" | "background-lightest-2" | "background-lightest-1" | "background-fixed-darker" | "background-fixed-dark" | "background-fixed" | "background-fixed-light" | "background-fixed-lighter" | "background-fixed-lightest-2" | "background-fixed-lightest-1" | undefined;
    colorHex?: string | undefined;
    placeholderColorName?: "background" | "transparent" | "primary-darker" | "primary-dark" | "primary" | "primary-light" | "primary-lighter" | "primary-lightest-2" | "primary-lightest-1" | "primary-fixed-darker" | "primary-fixed-dark" | "primary-fixed" | "primary-fixed-light" | "primary-fixed-lighter" | "primary-fixed-lightest-2" | "primary-fixed-lightest-1" | "secondary-darker" | "secondary-dark" | "secondary" | "secondary-light" | "secondary-lighter" | "secondary-lightest-2" | "secondary-lightest-1" | "secondary-fixed-darker" | "secondary-fixed-dark" | "secondary-fixed" | "secondary-fixed-light" | "secondary-fixed-lighter" | "secondary-fixed-lightest-2" | "secondary-fixed-lightest-1" | "tertiary-darker" | "tertiary-dark" | "tertiary" | "tertiary-light" | "tertiary-lighter" | "tertiary-lightest-2" | "tertiary-lightest-1" | "tertiary-fixed-darker" | "tertiary-fixed-dark" | "tertiary-fixed" | "tertiary-fixed-light" | "tertiary-fixed-lighter" | "tertiary-fixed-lightest-2" | "tertiary-fixed-lightest-1" | "black" | "black-2" | "black-light" | "black-lighter" | "black-lightest-2" | "black-lightest-1" | "black-fixed" | "black-fixed-light" | "black-fixed-lighter" | "black-fixed-lightest-2" | "black-fixed-lightest-1" | "white" | "white-2" | "white-light" | "white-lighter" | "white-lightest-2" | "white-lightest-1" | "white-fixed" | "white-fixed-light" | "white-fixed-lighter" | "white-fixed-lightest-2" | "white-fixed-lightest-1" | "gray-darker" | "gray-dark" | "gray" | "gray-light" | "gray-lighter" | "gray-lightest-2" | "gray-lightest-1" | "gray-fixed-darker" | "gray-fixed-dark" | "gray-fixed" | "gray-fixed-light" | "gray-fixed-lighter" | "gray-fixed-lightest-2" | "gray-fixed-lightest-1" | "success-darker" | "success-dark" | "success" | "success-light" | "success-lighter" | "success-lightest-2" | "success-lightest-1" | "success-fixed-darker" | "success-fixed-dark" | "success-fixed" | "success-fixed-light" | "success-fixed-lighter" | "success-fixed-lightest-2" | "success-fixed-lightest-1" | "warning-darker" | "warning-dark" | "warning" | "warning-light" | "warning-lighter" | "warning-lightest-2" | "warning-lightest-1" | "warning-fixed-darker" | "warning-fixed-dark" | "warning-fixed" | "warning-fixed-light" | "warning-fixed-lighter" | "warning-fixed-lightest-2" | "warning-fixed-lightest-1" | "danger-darker" | "danger-dark" | "danger" | "danger-light" | "danger-lighter" | "danger-lightest-2" | "danger-lightest-1" | "danger-fixed-darker" | "danger-fixed-dark" | "danger-fixed" | "danger-fixed-light" | "danger-fixed-lighter" | "danger-fixed-lightest-2" | "danger-fixed-lightest-1" | "info-darker" | "info-dark" | "info" | "info-light" | "info-lighter" | "info-lightest-2" | "info-lightest-1" | "info-fixed-darker" | "info-fixed-dark" | "info-fixed" | "info-fixed-light" | "info-fixed-lighter" | "info-fixed-lightest-2" | "info-fixed-lightest-1" | "background-darker" | "background-dark" | "background-light" | "background-lighter" | "background-lightest-2" | "background-lightest-1" | "background-fixed-darker" | "background-fixed-dark" | "background-fixed" | "background-fixed-light" | "background-fixed-lighter" | "background-fixed-lightest-2" | "background-fixed-lightest-1" | undefined;
    placeholderColorHex?: string | undefined;
    backgroundColorName?: "background" | "transparent" | "primary-darker" | "primary-dark" | "primary" | "primary-light" | "primary-lighter" | "primary-lightest-2" | "primary-lightest-1" | "primary-fixed-darker" | "primary-fixed-dark" | "primary-fixed" | "primary-fixed-light" | "primary-fixed-lighter" | "primary-fixed-lightest-2" | "primary-fixed-lightest-1" | "secondary-darker" | "secondary-dark" | "secondary" | "secondary-light" | "secondary-lighter" | "secondary-lightest-2" | "secondary-lightest-1" | "secondary-fixed-darker" | "secondary-fixed-dark" | "secondary-fixed" | "secondary-fixed-light" | "secondary-fixed-lighter" | "secondary-fixed-lightest-2" | "secondary-fixed-lightest-1" | "tertiary-darker" | "tertiary-dark" | "tertiary" | "tertiary-light" | "tertiary-lighter" | "tertiary-lightest-2" | "tertiary-lightest-1" | "tertiary-fixed-darker" | "tertiary-fixed-dark" | "tertiary-fixed" | "tertiary-fixed-light" | "tertiary-fixed-lighter" | "tertiary-fixed-lightest-2" | "tertiary-fixed-lightest-1" | "black" | "black-2" | "black-light" | "black-lighter" | "black-lightest-2" | "black-lightest-1" | "black-fixed" | "black-fixed-light" | "black-fixed-lighter" | "black-fixed-lightest-2" | "black-fixed-lightest-1" | "white" | "white-2" | "white-light" | "white-lighter" | "white-lightest-2" | "white-lightest-1" | "white-fixed" | "white-fixed-light" | "white-fixed-lighter" | "white-fixed-lightest-2" | "white-fixed-lightest-1" | "gray-darker" | "gray-dark" | "gray" | "gray-light" | "gray-lighter" | "gray-lightest-2" | "gray-lightest-1" | "gray-fixed-darker" | "gray-fixed-dark" | "gray-fixed" | "gray-fixed-light" | "gray-fixed-lighter" | "gray-fixed-lightest-2" | "gray-fixed-lightest-1" | "success-darker" | "success-dark" | "success" | "success-light" | "success-lighter" | "success-lightest-2" | "success-lightest-1" | "success-fixed-darker" | "success-fixed-dark" | "success-fixed" | "success-fixed-light" | "success-fixed-lighter" | "success-fixed-lightest-2" | "success-fixed-lightest-1" | "warning-darker" | "warning-dark" | "warning" | "warning-light" | "warning-lighter" | "warning-lightest-2" | "warning-lightest-1" | "warning-fixed-darker" | "warning-fixed-dark" | "warning-fixed" | "warning-fixed-light" | "warning-fixed-lighter" | "warning-fixed-lightest-2" | "warning-fixed-lightest-1" | "danger-darker" | "danger-dark" | "danger" | "danger-light" | "danger-lighter" | "danger-lightest-2" | "danger-lightest-1" | "danger-fixed-darker" | "danger-fixed-dark" | "danger-fixed" | "danger-fixed-light" | "danger-fixed-lighter" | "danger-fixed-lightest-2" | "danger-fixed-lightest-1" | "info-darker" | "info-dark" | "info" | "info-light" | "info-lighter" | "info-lightest-2" | "info-lightest-1" | "info-fixed-darker" | "info-fixed-dark" | "info-fixed" | "info-fixed-light" | "info-fixed-lighter" | "info-fixed-lightest-2" | "info-fixed-lightest-1" | "background-darker" | "background-dark" | "background-light" | "background-lighter" | "background-lightest-2" | "background-lightest-1" | "background-fixed-darker" | "background-fixed-dark" | "background-fixed" | "background-fixed-light" | "background-fixed-lighter" | "background-fixed-lightest-2" | "background-fixed-lightest-1" | undefined;
    backgroundColorHex?: string | undefined;
    textError?: string | undefined;
    onChange?: ((values: string[]) => void) | undefined;
    autoComplete?: string | undefined;
    LeftIcon?: FC<IconProps> | undefined;
    RightIcon?: FC<IconProps> | undefined;
    leftIconColorName?: "background" | "transparent" | "primary-darker" | "primary-dark" | "primary" | "primary-light" | "primary-lighter" | "primary-lightest-2" | "primary-lightest-1" | "primary-fixed-darker" | "primary-fixed-dark" | "primary-fixed" | "primary-fixed-light" | "primary-fixed-lighter" | "primary-fixed-lightest-2" | "primary-fixed-lightest-1" | "secondary-darker" | "secondary-dark" | "secondary" | "secondary-light" | "secondary-lighter" | "secondary-lightest-2" | "secondary-lightest-1" | "secondary-fixed-darker" | "secondary-fixed-dark" | "secondary-fixed" | "secondary-fixed-light" | "secondary-fixed-lighter" | "secondary-fixed-lightest-2" | "secondary-fixed-lightest-1" | "tertiary-darker" | "tertiary-dark" | "tertiary" | "tertiary-light" | "tertiary-lighter" | "tertiary-lightest-2" | "tertiary-lightest-1" | "tertiary-fixed-darker" | "tertiary-fixed-dark" | "tertiary-fixed" | "tertiary-fixed-light" | "tertiary-fixed-lighter" | "tertiary-fixed-lightest-2" | "tertiary-fixed-lightest-1" | "black" | "black-2" | "black-light" | "black-lighter" | "black-lightest-2" | "black-lightest-1" | "black-fixed" | "black-fixed-light" | "black-fixed-lighter" | "black-fixed-lightest-2" | "black-fixed-lightest-1" | "white" | "white-2" | "white-light" | "white-lighter" | "white-lightest-2" | "white-lightest-1" | "white-fixed" | "white-fixed-light" | "white-fixed-lighter" | "white-fixed-lightest-2" | "white-fixed-lightest-1" | "gray-darker" | "gray-dark" | "gray" | "gray-light" | "gray-lighter" | "gray-lightest-2" | "gray-lightest-1" | "gray-fixed-darker" | "gray-fixed-dark" | "gray-fixed" | "gray-fixed-light" | "gray-fixed-lighter" | "gray-fixed-lightest-2" | "gray-fixed-lightest-1" | "success-darker" | "success-dark" | "success" | "success-light" | "success-lighter" | "success-lightest-2" | "success-lightest-1" | "success-fixed-darker" | "success-fixed-dark" | "success-fixed" | "success-fixed-light" | "success-fixed-lighter" | "success-fixed-lightest-2" | "success-fixed-lightest-1" | "warning-darker" | "warning-dark" | "warning" | "warning-light" | "warning-lighter" | "warning-lightest-2" | "warning-lightest-1" | "warning-fixed-darker" | "warning-fixed-dark" | "warning-fixed" | "warning-fixed-light" | "warning-fixed-lighter" | "warning-fixed-lightest-2" | "warning-fixed-lightest-1" | "danger-darker" | "danger-dark" | "danger" | "danger-light" | "danger-lighter" | "danger-lightest-2" | "danger-lightest-1" | "danger-fixed-darker" | "danger-fixed-dark" | "danger-fixed" | "danger-fixed-light" | "danger-fixed-lighter" | "danger-fixed-lightest-2" | "danger-fixed-lightest-1" | "info-darker" | "info-dark" | "info" | "info-light" | "info-lighter" | "info-lightest-2" | "info-lightest-1" | "info-fixed-darker" | "info-fixed-dark" | "info-fixed" | "info-fixed-light" | "info-fixed-lighter" | "info-fixed-lightest-2" | "info-fixed-lightest-1" | "background-darker" | "background-dark" | "background-light" | "background-lighter" | "background-lightest-2" | "background-lightest-1" | "background-fixed-darker" | "background-fixed-dark" | "background-fixed" | "background-fixed-light" | "background-fixed-lighter" | "background-fixed-lightest-2" | "background-fixed-lightest-1" | undefined;
    leftIconColorHex?: string | undefined;
    rightIconColorName?: "background" | "transparent" | "primary-darker" | "primary-dark" | "primary" | "primary-light" | "primary-lighter" | "primary-lightest-2" | "primary-lightest-1" | "primary-fixed-darker" | "primary-fixed-dark" | "primary-fixed" | "primary-fixed-light" | "primary-fixed-lighter" | "primary-fixed-lightest-2" | "primary-fixed-lightest-1" | "secondary-darker" | "secondary-dark" | "secondary" | "secondary-light" | "secondary-lighter" | "secondary-lightest-2" | "secondary-lightest-1" | "secondary-fixed-darker" | "secondary-fixed-dark" | "secondary-fixed" | "secondary-fixed-light" | "secondary-fixed-lighter" | "secondary-fixed-lightest-2" | "secondary-fixed-lightest-1" | "tertiary-darker" | "tertiary-dark" | "tertiary" | "tertiary-light" | "tertiary-lighter" | "tertiary-lightest-2" | "tertiary-lightest-1" | "tertiary-fixed-darker" | "tertiary-fixed-dark" | "tertiary-fixed" | "tertiary-fixed-light" | "tertiary-fixed-lighter" | "tertiary-fixed-lightest-2" | "tertiary-fixed-lightest-1" | "black" | "black-2" | "black-light" | "black-lighter" | "black-lightest-2" | "black-lightest-1" | "black-fixed" | "black-fixed-light" | "black-fixed-lighter" | "black-fixed-lightest-2" | "black-fixed-lightest-1" | "white" | "white-2" | "white-light" | "white-lighter" | "white-lightest-2" | "white-lightest-1" | "white-fixed" | "white-fixed-light" | "white-fixed-lighter" | "white-fixed-lightest-2" | "white-fixed-lightest-1" | "gray-darker" | "gray-dark" | "gray" | "gray-light" | "gray-lighter" | "gray-lightest-2" | "gray-lightest-1" | "gray-fixed-darker" | "gray-fixed-dark" | "gray-fixed" | "gray-fixed-light" | "gray-fixed-lighter" | "gray-fixed-lightest-2" | "gray-fixed-lightest-1" | "success-darker" | "success-dark" | "success" | "success-light" | "success-lighter" | "success-lightest-2" | "success-lightest-1" | "success-fixed-darker" | "success-fixed-dark" | "success-fixed" | "success-fixed-light" | "success-fixed-lighter" | "success-fixed-lightest-2" | "success-fixed-lightest-1" | "warning-darker" | "warning-dark" | "warning" | "warning-light" | "warning-lighter" | "warning-lightest-2" | "warning-lightest-1" | "warning-fixed-darker" | "warning-fixed-dark" | "warning-fixed" | "warning-fixed-light" | "warning-fixed-lighter" | "warning-fixed-lightest-2" | "warning-fixed-lightest-1" | "danger-darker" | "danger-dark" | "danger" | "danger-light" | "danger-lighter" | "danger-lightest-2" | "danger-lightest-1" | "danger-fixed-darker" | "danger-fixed-dark" | "danger-fixed" | "danger-fixed-light" | "danger-fixed-lighter" | "danger-fixed-lightest-2" | "danger-fixed-lightest-1" | "info-darker" | "info-dark" | "info" | "info-light" | "info-lighter" | "info-lightest-2" | "info-lightest-1" | "info-fixed-darker" | "info-fixed-dark" | "info-fixed" | "info-fixed-light" | "info-fixed-lighter" | "info-fixed-lightest-2" | "info-fixed-lightest-1" | "background-darker" | "background-dark" | "background-light" | "background-lighter" | "background-lightest-2" | "background-lightest-1" | "background-fixed-darker" | "background-fixed-dark" | "background-fixed" | "background-fixed-light" | "background-fixed-lighter" | "background-fixed-lightest-2" | "background-fixed-lightest-1" | undefined;
    rightIconColorHex?: string | undefined;
    leftIconSize?: number | undefined;
    rightIconSize?: number | undefined;
    leftChildren?: ReactNode;
    rightChildren?: ReactNode;
    min?: number | undefined;
    max?: number | undefined;
    outline?: boolean | undefined;
    description?: string | undefined;
    width?: string | number | undefined;
    maxWidth?: string | number | undefined;
    minWidth?: string | number | undefined;
    info?: ReactNode;
    data?: DOMStringMap | undefined;
    type?: "number" | "time" | "text" | "search" | "color" | "hidden" | "date" | "datetime-local" | "email" | "month" | "password" | "tel" | "url" | "week" | undefined;
    defaultValues?: string[] | undefined;
} & react.RefAttributes<HTMLInputElement>>;

export { MultiInputField, MultiInputFieldCSS, MultiInputFieldGap, MultiInputFieldPadding, MultiInputFieldProps, MultiInputFieldType, multiInputFieldGap, multiInputFieldPadding, multiInputFieldType };
